@@ -1,5 +1,5 @@
 /* kw.c - Keyword functions.
-   Copyright (C) 2000 Free Software Foundation, Inc.
+   Copyright (C) 2001 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -186,7 +186,7 @@ lookahead (char **str)
     case 'A':
       if (((*str)[1]=='n' || (*str)[1]=='N')
           && ((*str)[2]=='d' || (*str)[2]=='D')
-          && (is_space ((*str)[3]) || (*str)[3]=='\0'))
+          && (is_space ((*str)[3]) || (*str)[3]=='(' || (*str)[3]=='\0'))
         {
           *str += 3;
           return AND;
@@ -198,7 +198,7 @@ lookahead (char **str)
       case 'o':
       case 'O':
         if (((*str)[2]=='t' || (*str)[2]=='T')
-            && (is_space ((*str)[3]) || (*str)[3]=='\0'))
+            && (is_space ((*str)[3]) || (*str)[3]=='(' || (*str)[3]=='\0'))
           {
             *str += 3;
             return NOT;
@@ -208,7 +208,7 @@ lookahead (char **str)
       case 'E':
         if (((*str)[2]=='a' || (*str)[2]=='A')
             && ((*str)[3]=='r' || (*str)[3]=='R')
-            && (is_space ((*str)[4]) || (*str)[4]=='\0'))
+            && (is_space ((*str)[4]) || (*str)[4]=='(' || (*str)[4]=='\0'))
           {
             *str += 4;
             return NEAR;
@@ -219,7 +219,7 @@ lookahead (char **str)
     case 'o':
     case 'O':
       if (((*str)[1]=='r' || (*str)[1]=='R')
-          && (is_space ((*str)[2]) || (*str)[2]=='\0'))
+          && (is_space ((*str)[2]) || (*str)[2]=='(' || (*str)[2]=='\0'))
         {
           *str += 2;
           return OR;
@@ -490,6 +490,7 @@ void
 kw_prep (enum extension type)
 {
   kw->fpos = 0;
+  kw->words = 1;
   kw->state = SRCH;
   kw->context_table = kw->cstack;
   *kw->context_table = NULL;
